# Oups ...

Je ne parviens pas à trouver les mises à jour. Êtes-vous connecté à Internet ?

Pour savoir si une nouvelle version d'OpenSesame est disponible, rendez-vous sur

- <http://osdoc.cogsci.nl>
